==> jc-1.4.0.tar.gz: java__5fcup/Main.h <==
// public class java_cup.Main

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9b9da8a310719ea6 java__5fcup_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_Main_H_
#define _JC_java__5fcup_Main_H_

// Forward structure declarations
struct _jc_java_io_BufferedInputStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_parse__5faction__5ftable$object;
struct _jc_java__5fcup_parse__5freduce__5ftable$object;

// Typedefs
typedef struct _jc_java__5fcup_Main$sub_refs	_jc_java__5fcup_Main$sub_refs;
typedef struct _jc_java__5fcup_Main$sub_nonrefs	_jc_java__5fcup_Main$sub_nonrefs;
typedef struct _jc_java__5fcup_Main$refs	_jc_java__5fcup_Main$refs;
typedef struct _jc_java__5fcup_Main$nonrefs	_jc_java__5fcup_Main$nonrefs;
typedef struct _jc_java__5fcup_Main$object	_jc_java__5fcup_Main$object;

typedef struct _jc_java__5fcup_Main$fields_struct	_jc_java__5fcup_Main$fields_struct;
typedef const struct _jc_java__5fcup_Main$vmethods	_jc_java__5fcup_Main$vmethods;
typedef const struct _jc_java__5fcup_Main$vtable	_jc_java__5fcup_Main$vtable;
typedef const struct _jc_java__5fcup_Main$vtype	_jc_java__5fcup_Main$vtype;

// Class fields structure
struct _jc_java__5fcup_Main$fields_struct {
	struct _jc_java__5fcup_parse__5faction__5ftable$object	*action__5ftable;
	struct _jc_java_io_BufferedInputStream$object	*input__5ffile;
	struct _jc_java_io_PrintWriter$object	*parser__5fclass__5ffile;
	struct _jc_java__5fcup_parse__5freduce__5ftable$object	*reduce__5ftable;
	struct _jc_java__5fcup_lalr__5fstate$object	*start__5fstate;
	struct _jc_java_io_PrintWriter$object	*symbol__5fclass__5ffile;
	jlong	build__5fend;
	jlong	check__5fend;
	jlong	dump__5fend;
	jlong	emit__5fend;
	jlong	final__5ftime;
	jlong	first__5fend;
	jlong	machine__5fend;
	jlong	nullability__5fend;
	jlong	parse__5fend;
	jlong	prelim__5fend;
	jlong	reduce__5fcheck__5fend;
	jlong	start__5ftime;
	jlong	table__5fend;
	jint	expect__5fconflicts;
	jboolean	include__5fnon__5fterms;
	jboolean	lr__5fvalues;
	jboolean	no__5fsummary;
	jboolean	opt__5fcompact__5fred;
	jboolean	opt__5fdo__5fdebug;
	jboolean	opt__5fdump__5fgrammar;
	jboolean	opt__5fdump__5fstates;
	jboolean	opt__5fdump__5ftables;
	jboolean	opt__5fshow__5ftiming;
	jboolean	print__5fprogress;
	jboolean	suppress__5fscanner;
	jboolean	sym__5finterface;
};
extern _jc_java__5fcup_Main$fields_struct _jc_java__5fcup_Main$class_fields;

// Constructors
extern void _jc_java__5fcup_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_Main$object *);

// Static methods
extern void _jc_java__5fcup_Main$method$_clinit$a816641e0ba8bfef(_jc_env *);
extern void _jc_java__5fcup_Main$method$build__5fparser$97eab55a12260e94(_jc_env *);
extern void _jc_java__5fcup_Main$method$check__5funused$1582bf5d23ce55a4(_jc_env *);
extern void _jc_java__5fcup_Main$method$close__5ffiles$900b9c6b2312b88e(_jc_env *);
extern void _jc_java__5fcup_Main$method$dump__5fgrammar$cc266bc0037f8099(_jc_env *);
extern void _jc_java__5fcup_Main$method$dump__5fmachine$1a0be3c2c40119f4(_jc_env *);
extern void _jc_java__5fcup_Main$method$dump__5ftables$a43e4db98ba95007(_jc_env *);
extern void _jc_java__5fcup_Main$method$emit__5fparser$c51250b6dd95fcc4(_jc_env *);
extern void _jc_java__5fcup_Main$method$emit__5fsummary$f782442b1f815715(_jc_env *, jboolean);
extern void _jc_java__5fcup_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *);
extern void _jc_java__5fcup_Main$method$open__5ffiles$f00bd8d4f002ae49(_jc_env *);
extern void _jc_java__5fcup_Main$method$parse__5fargs$f2700e65562da123(_jc_env *, struct _jc_object_array *);
extern void _jc_java__5fcup_Main$method$parse__5fgrammar__5fspec$56b3c9ead4d6537f(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_java__5fcup_Main$method$plural$f970fc300b661f74(_jc_env *, jint);
extern void _jc_java__5fcup_Main$method$show__5ftimes$3d436a23b30a8c6c(_jc_env *);
extern struct _jc_java_lang_String$object *_jc_java__5fcup_Main$method$timestr$dea33283922b0c28(_jc_env *, jlong, jlong);
extern void _jc_java__5fcup_Main$method$usage$fb3ec0585c46bea4(_jc_env *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java__5fcup_Main$vmethods {
};

// Vtable
struct _jc_java__5fcup_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_Main$vmethods	java__5fcup_Main;
};

// Vtype
struct _jc_java__5fcup_Main$vtype {
	_jc_type			type;
	_jc_java__5fcup_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_Main$refs {
    _jc_java__5fcup_Main$sub_refs	java__5fcup_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_Main$sub_nonrefs	java__5fcup_Main;
};

// Object instance structure
struct _jc_java__5fcup_Main$object {
	_jc_java__5fcup_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_Main$vtype	*vtype;
	_jc_java__5fcup_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_Main$vtype _jc_java__5fcup_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_Main$class_object;

#endif	/* _JC_java__5fcup_Main_H_ */

==> jc-1.4.6.tar.gz: java__5fcup/Main.h <==
// public class java_cup.Main

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9b9da8a310719ea6 java__5fcup_Main

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java__5fcup_Main_H_
#define _JC_java__5fcup_Main_H_

// Forward structure declarations
struct _jc_java_io_BufferedInputStream$object;
struct _jc_java_io_PrintWriter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_java__5fcup_lalr__5fstate$object;
struct _jc_java__5fcup_parse__5faction__5ftable$object;
struct _jc_java__5fcup_parse__5freduce__5ftable$object;

// Typedefs
typedef struct _jc_java__5fcup_Main$sub_refs	_jc_java__5fcup_Main$sub_refs;
typedef struct _jc_java__5fcup_Main$sub_nonrefs	_jc_java__5fcup_Main$sub_nonrefs;
typedef struct _jc_java__5fcup_Main$refs	_jc_java__5fcup_Main$refs;
typedef struct _jc_java__5fcup_Main$nonrefs	_jc_java__5fcup_Main$nonrefs;
typedef struct _jc_java__5fcup_Main$object	_jc_java__5fcup_Main$object;

typedef struct _jc_java__5fcup_Main$fields_struct	_jc_java__5fcup_Main$fields_struct;
typedef const struct _jc_java__5fcup_Main$vmethods	_jc_java__5fcup_Main$vmethods;
typedef const struct _jc_java__5fcup_Main$vtable	_jc_java__5fcup_Main$vtable;
typedef const struct _jc_java__5fcup_Main$vtype	_jc_java__5fcup_Main$vtype;

// Class fields structure
struct _jc_java__5fcup_Main$fields_struct {
	struct _jc_java__5fcup_parse__5faction__5ftable$object	*action__5ftable;
	struct _jc_java_io_BufferedInputStream$object	*input__5ffile;
	struct _jc_java_io_PrintWriter$object	*parser__5fclass__5ffile;
	struct _jc_java__5fcup_parse__5freduce__5ftable$object	*reduce__5ftable;
	struct _jc_java__5fcup_lalr__5fstate$object	*start__5fstate;
	struct _jc_java_io_PrintWriter$object	*symbol__5fclass__5ffile;
	jlong	build__5fend;
	jlong	check__5fend;
	jlong	dump__5fend;
	jlong	emit__5fend;
	jlong	final__5ftime;
	jlong	first__5fend;
	jlong	machine__5fend;
	jlong	nullability__5fend;
	jlong	parse__5fend;
	jlong	prelim__5fend;
	jlong	reduce__5fcheck__5fend;
	jlong	start__5ftime;
	jlong	table__5fend;
	jint	expect__5fconflicts;
	jboolean	include__5fnon__5fterms;
	jboolean	lr__5fvalues;
	jboolean	no__5fsummary;
	jboolean	opt__5fcompact__5fred;
	jboolean	opt__5fdo__5fdebug;
	jboolean	opt__5fdump__5fgrammar;
	jboolean	opt__5fdump__5fstates;
	jboolean	opt__5fdump__5ftables;
	jboolean	opt__5fshow__5ftiming;
	jboolean	print__5fprogress;
	jboolean	suppress__5fscanner;
	jboolean	sym__5finterface;
};
extern _jc_java__5fcup_Main$fields_struct _jc_java__5fcup_Main$class_fields;

// Constructors
extern void _jc_java__5fcup_Main$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java__5fcup_Main$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java__5fcup_Main$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$build__5fparser$97eab55a12260e94(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$check__5funused$1582bf5d23ce55a4(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$close__5ffiles$900b9c6b2312b88e(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$dump__5fgrammar$cc266bc0037f8099(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$dump__5fmachine$1a0be3c2c40119f4(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$dump__5ftables$a43e4db98ba95007(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$emit__5fparser$c51250b6dd95fcc4(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$emit__5fsummary$f782442b1f815715(_jc_env *, jboolean) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$main$bc98a92695db8a73(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$open__5ffiles$f00bd8d4f002ae49(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$parse__5fargs$f2700e65562da123(_jc_env *, struct _jc_object_array *) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$parse__5fgrammar__5fspec$56b3c9ead4d6537f(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java__5fcup_Main$method$plural$f970fc300b661f74(_jc_env *, jint) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$show__5ftimes$3d436a23b30a8c6c(_jc_env *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java__5fcup_Main$method$timestr$dea33283922b0c28(_jc_env *, jlong, jlong) _JC_JCNI_ATTR;
extern void _jc_java__5fcup_Main$method$usage$fb3ec0585c46bea4(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java__5fcup_Main$vmethods {
};

// Vtable
struct _jc_java__5fcup_Main$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java__5fcup_Main$vmethods	java__5fcup_Main;
};

// Vtype
struct _jc_java__5fcup_Main$vtype {
	_jc_type			type;
	_jc_java__5fcup_Main$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java__5fcup_Main$sub_refs {
};

// Reference instance fields (object)
struct _jc_java__5fcup_Main$refs {
    _jc_java__5fcup_Main$sub_refs	java__5fcup_Main;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java__5fcup_Main$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java__5fcup_Main$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java__5fcup_Main$sub_nonrefs	java__5fcup_Main;
};

// Object instance structure
struct _jc_java__5fcup_Main$object {
	_jc_java__5fcup_Main$refs	refs[0];
	_jc_word		lockword;
	_jc_java__5fcup_Main$vtype	*vtype;
	_jc_java__5fcup_Main$nonrefs	nonrefs;
};

// Type structure
extern _jc_java__5fcup_Main$vtype _jc_java__5fcup_Main$type;

// Array types class info structures
_JC_DECL_ARRAYS(java__5fcup_Main, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java__5fcup_Main$class_object;

#endif	/* _JC_java__5fcup_Main_H_ */
